==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/XmlFieldBinding.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface XmlFieldBinding extends BusinessEntity {     String EXT_XMLFIELDBINDING = "XmlFieldBinding";
     String FIELD_XMLFIELDBINDING_XMLFIELD = "xmlField";
     String FQ_FIELD_XMLFIELDBINDING_XMLFIELD = EXT_XMLFIELDBINDING + ".xmlField";
     String FIELD_XMLFIELDBINDING_FORMFIELD = "formField";
     String FQ_FIELD_XMLFIELDBINDING_FORMFIELD = EXT_XMLFIELDBINDING + ".formField";
     String FIELD_XMLFIELDBINDING_DEFAULTVALUE = "defaultValue";
     String FQ_FIELD_XMLFIELDBINDING_DEFAULTVALUE = EXT_XMLFIELDBINDING + ".defaultValue";
    /**
     * getXmlField :
     * @return Set<String> 
     */

     Set<String> getXmlField();

    /**
     * addXmlField :
     * @param element 
     */

     void addXmlField(String element);

    /**
     * removeXmlField :
     * @param element 
     */

     void removeXmlField(String element);

    /**
     * clearXmlField :
     */

     void clearXmlField();

    /**
     * getFormField :
     * @return String 
     */

     String getFormField();

    /**
     * setFormField :
     * @param formField 
     */

     void setFormField(String formField);

    /**
     * getDefaultValue :
     * @return String 
     */

     String getDefaultValue();

    /**
     * setDefaultValue :
     * @param defaultValue 
     */

     void setDefaultValue(String defaultValue);


} //XmlFieldBinding

==> vradi-entities-0.4.0-sources.jar: com/jurismarches/vradi/entities/XmlFieldBinding.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface XmlFieldBinding extends BusinessEntity {     String EXT_XMLFIELDBINDING = "XmlFieldBinding";
     String FIELD_XMLFIELDBINDING_XMLFIELD = "xmlField";
     String FQ_FIELD_XMLFIELDBINDING_XMLFIELD = EXT_XMLFIELDBINDING + ".xmlField";
     String FIELD_XMLFIELDBINDING_FORMFIELD = "formField";
     String FQ_FIELD_XMLFIELDBINDING_FORMFIELD = EXT_XMLFIELDBINDING + ".formField";
     String FIELD_XMLFIELDBINDING_DEFAULTVALUE = "defaultValue";
     String FQ_FIELD_XMLFIELDBINDING_DEFAULTVALUE = EXT_XMLFIELDBINDING + ".defaultValue";
    /**
     * getXmlField :
     * @return Set<String> 
     */

     Set<String> getXmlField();

    /**
     * addXmlField :
     * @param element 
     */

     void addXmlField(String element);

    /**
     * removeXmlField :
     * @param element 
     */

     void removeXmlField(String element);

    /**
     * clearXmlField :
     */

     void clearXmlField();

    /**
     * getFormField :
     * @return String 
     */

     String getFormField();

    /**
     * setFormField :
     * @param formField 
     */

     void setFormField(String formField);

    /**
     * getDefaultValue :
     * @return String 
     */

     String getDefaultValue();

    /**
     * setDefaultValue :
     * @param defaultValue 
     */

     void setDefaultValue(String defaultValue);


} //XmlFieldBinding
